@@ -1,15 +1,16 @@
 from pymemcache.client.murmur3 import murmur3_32
 
 
-class RendezvousHash(object):
+class RendezvousHash:
     """
-        Implements the Highest Random Weight (HRW) hashing algorithm most
-        commonly referred to as rendezvous hashing.
+    Implements the Highest Random Weight (HRW) hashing algorithm most
+    commonly referred to as rendezvous hashing.
 
-        Originally developed as part of python-clandestined.
+    Originally developed as part of python-clandestined.
 
-        Copyright (c) 2014 Ernest W. Durbin III
+    Copyright (c) 2014 Ernest W. Durbin III
     """
+
     def __init__(self, nodes=None, seed=0, hash_function=murmur3_32):
         """
         Constructor.
@@ -35,8 +36,7 @@ class RendezvousHash(object):
         winner = None
 
         for node in self.nodes:
-            score = self.hash_function(
-                "%s-%s" % (node, key))
+            score = self.hash_function(f"{node}-{key}")
 
             if score > high_score:
                 (high_score, winner) = (score, node)
